function [ startup_messages ] = extract_startup_message( p_combined_float )
%DECODE_STARTUP_MESSAGE Extracts the startup messages of the given float
%   Detailed explanation goes here

%% Initialize return variable
startup_messages = false;

%% Check if float is not empty
if ~isfield(p_combined_float, 'DECODED_SBD')
    % no data available
    return
end

%% Search startup messages and get them into the awi structure

startup_messages = {};

% get fieldnames of every profile
profile_fieldnames = fieldnames(p_combined_float.DECODED_SBD);

for i = 1:length(profile_fieldnames)
    
    if ~strcmp( ...
               p_combined_float.DECODED_SBD.(profile_fieldnames{i}).DATATYPE, ...
               'Startup Test Message' ...
              )
			% everything that is not a profile or a test message is being ignored
            continue
    else
		% extract the message
        current_message = p_combined_float.DECODED_SBD.(profile_fieldnames{i});
        startup_messages{end + 1} = struct();
        startup_messages{end}.float_serial_number = current_message.SERIAL;
        startup_messages{end}.software_version = current_message.SOFTWARE;
        startup_messages{end}.real_time_clock = current_message.RTC;
        startup_messages{end}.piston_max_count = current_message.PISTON_MAX;
        startup_messages{end}.piston_min_count = current_message.PISTON_MIN;
        startup_messages{end}.cpu_battery_voltage = current_message.BATT_CPU;
        startup_messages{end}.pump_battery_voltage = current_message.BATT_PMP;
        startup_messages{end}.ext_battery_voltage = current_message.BATT_EXT;
        startup_messages{end}.pressure_tube_surface = current_message.PRES_TUBE_SURFACE;
        startup_messages{end}.pressure_profile_depth = current_message.PRES_PROFILE;
        startup_messages{end}.transmission_time = current_message.TIME_TX;
        startup_messages{end}.parking_sample_time = current_message.TIME_PARKSAMPLE;
        startup_messages{end}.cycle_time = current_message.TIME_CYCLE;
        startup_messages{end}.descent_mode = current_message.DESCENT_MODE;
        startup_messages{end}.start_recovery = current_message.RECOVERY_START;
        startup_messages{end}.descent_speed = current_message.DESCENT_SPEED;
        startup_messages{end}.ice_detection_temperature = current_message.TEMP_ICEDETECT;
        startup_messages{end}.recovery_transmission = current_message.RECOVERY_TX;
        startup_messages{end}.recovery_no_transmission = current_message.RECOVERY_NOTX;
        startup_messages{end}.gps_datetime = current_message.GPS_DATETIME;
        startup_messages{end}.gps_lat = current_message.GPS_LAT;
        startup_messages{end}.gps_lon = current_message.GPS_LON;
    end
    
end

end

