function [ imapstore ] = connect( p_config )
%CONNECT Connects with the specified server details where nemo emails are stored.
%  This functions connects to the mail server given in the config
%  parameter. Therefore the java library javax.mail.jar (javaMail) and
%  activation.jar (JavaBeans Activation Framework) is required. There is no
%  disconnect function, use 'clear imapstore' instead.
%  javaMail Documentation: https://javamail.java.net/nonav/docs/api/
%
%  Parameter:
%  p_config:    struct, containing the content of the nemo config file.
%
%  Returns:
%  imapstore:   IMAPSSLSTORE/IMAPSTORE java object, false on fail.

%% Initialize return variable
imapstore = false;

%% Parameter check
parameter_error = false;

if (~isstruct(p_config))
    parameter_error = true;
end

if (parameter_error) % display error message
    disp([ mfilename ': Wrong parameter! Please check your input parameters carefully!']);
    return;
else % do some cleanup
    clear parameter_error;
end

if (~isfield(p_config, 'MAIL'))
    disp('No MAIL section found in p_config.');
    return;
end

%% Prepare connection
try
    props = java.util.Properties; % default imap properties
    props.put('mail.imap.port', p_config.MAIL.port);
    props.put('mail.imap.timeout', p_config.MAIL.imap_timeout);
    props.put('mail.imaps.connectiontimeout', p_config.MAIL.imaps_connection_timeout);
    session = javax.mail.Session.getInstance(props); % create a session
    if (p_config.MAIL.ssl) % get the ssl store object
        imapstore = session.getStore('imaps');
    else % get the store object
        imapstore = session.getStore('imap');
    end
    imapstore.connect( ...
        p_config.MAIL.server, ...
        p_config.MAIL.port, ...
        p_config.MAIL.username, ...
        p_config.MAIL.password ...
    );
catch
    warning('Something failed during the establishment of the imap connection!');
    imapstore = false;
    return;
end

end

